window.Gleam.initSearch([{"doc":"youid","title":"youid","content":"# youid\n\nGenerate and parse UUIDs.\n\n[![Package Version](https://img.shields.io/hexpm/v/youid)](https://hex.pm/packages/youid)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/youid/)\n\n```sh\ngleam add youid\n```\n```gleam\nimport youid/uuid\n\npub fn main() {\n  uuid.v4_string()\n  // -&gt; &quot;f55f6957-534b-45a7-af22-a1591431bc1f&quot;\n}\n```\n\nSpec conformant UUID v1, v3, v4, and v5 generation.\n\nSpec conformant UUID decoding for v1, v2, v3, v4, and v5.\n\nSpec: [https://www.ietf.org/rfc/rfc4122.txt](https://www.ietf.org/rfc/rfc4122.txt)\n\nWikipedia: [https://en.wikipedia.org/wiki/uuid](https://en.wikipedia.org/wiki/uuid)\n\nUnless you have a specific reason otherwise, you probably either want the\nrandom v4 or the time-based v1 version.\n\nCurrently this library only works on the Erlang target as the JavaScript target\ndoes not yet support non-byte aligned bit arrays.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/youid&gt;.\n\nMany thanks to Gregggreg for [the original version][original] of this library.\n\n[original]: https://gitlab.com/greggreg/gleam_uuid\n","url":"index.html"},{"doc":"youid/uuid","title":"Format","content":"pub type Format {\n  String\n  Hex\n  Urn\n}\n Supported string formats\nString\n Standad hex string with dashes\n\nHex\n Hex string with no dashes\n\nUrn\n Standard hex string with dashes prepended with &quot;urn:uuid:&quot;\n\nSynonyms:\nyouid/uuid.Format\nyouid/uuid Format","url":"youid/uuid.html#Format"},{"doc":"youid/uuid","title":"Uuid","content":"pub opaque type Uuid\n Opaque type for holding onto a UUID.\n Opaque so you know that if you have a UUID it is valid.\n\nSynonyms:\nyouid/uuid.Uuid\nyouid/uuid Uuid","url":"youid/uuid.html#Uuid"},{"doc":"youid/uuid","title":"V1ClockSeq","content":"pub type V1ClockSeq {\n  RandomClockSeq\n  CustomClockSeq(BitArray)\n}\n How to generate the clock sequence for a V1 UUID\nRandomClockSeq\n Will be generated randomly.\n\nCustomClockSeq(BitArray)\n Will be the provided bit string, must be exactly 14 bits.\n\nSynonyms:\nyouid/uuid.V1ClockSeq\nyouid/uuid V1ClockSeq","url":"youid/uuid.html#V1ClockSeq"},{"doc":"youid/uuid","title":"V1Node","content":"pub type V1Node {\n  DefaultNode\n  RandomNode\n  CustomNode(String)\n}\n How to generate the node for a V1 UUID.\nDefaultNode\n Will first attempt to use the network cards MAC address, then fall back to random\n\nRandomNode\n Will be random\n\nCustomNode(String)\n Will be the provided sting, must be 12 characters long and valid hex\n\nSynonyms:\nyouid/uuid.V1Node\nyouid/uuid V1Node","url":"youid/uuid.html#V1Node"},{"doc":"youid/uuid","title":"Variant","content":"pub type Variant {\n  ReservedFuture\n  ReservedMicrosoft\n  ReservedNcs\n  Rfc4122\n}\n Possible UUID variants.\n This library only produces Rfc4122 variant UUIDs but can decode all variants\nReservedFuture\n\n\nReservedMicrosoft\n\n\nReservedNcs\n\n\nRfc4122\n\n\nSynonyms:\nyouid/uuid.Variant\nyouid/uuid Variant","url":"youid/uuid.html#Variant"},{"doc":"youid/uuid","title":"Version","content":"pub type Version {\n  V1\n  V2\n  V3\n  V4\n  V5\n  VUnknown\n}\n Possible UUID versions.\n This library only creates V1, V3, V4 and V5 UUIDs but can decode all versions\nV1\n\n\nV2\n\n\nV3\n\n\nV4\n\n\nV5\n\n\nVUnknown\n\n\nSynonyms:\nyouid/uuid.Version\nyouid/uuid Version","url":"youid/uuid.html#Version"},{"doc":"youid/uuid","title":"clock_sequence","content":"pub fn clock_sequence(uuid: Uuid) -&gt; Int\n Determine the clock sequence of a UUID\n This is only relevant to a V1 UUID\nSynonyms:\nyouid/uuid.clock_sequence\nyouid/uuid clock_sequence","url":"youid/uuid.html#clock_sequence"},{"doc":"youid/uuid","title":"dns_uuid","content":"pub fn dns_uuid() -&gt; Uuid\n dns namespace UUID provided by the spec, only useful for v3 and v5\nSynonyms:\nyouid/uuid.dns_uuid\nyouid/uuid dns_uuid","url":"youid/uuid.html#dns_uuid"},{"doc":"youid/uuid","title":"format","content":"pub fn format(uuid: Uuid, format: Format) -&gt; String\n Convert a UUID to one of the supported string formats\nSynonyms:\nyouid/uuid.format\nyouid/uuid format","url":"youid/uuid.html#format"},{"doc":"youid/uuid","title":"from_string","content":"pub fn from_string(in: String) -&gt; Result(Uuid, Nil)\n Attempt to decode a UUID from a string. Supports strings formatted in the same\n ways this library will output them. Hex with dashes, hex without dashes and\n hex with or without dashes prepended with &quot;urn:uuid:&quot;\nSynonyms:\nyouid/uuid.from_string\nyouid/uuid from_string","url":"youid/uuid.html#from_string"},{"doc":"youid/uuid","title":"node","content":"pub fn node(uuid: Uuid) -&gt; String\n Determine the node of a UUID\n This is only relevant to a V1 UUID\nSynonyms:\nyouid/uuid.node\nyouid/uuid node","url":"youid/uuid.html#node"},{"doc":"youid/uuid","title":"oid_uuid","content":"pub fn oid_uuid() -&gt; Uuid\n oid namespace UUID provided by the spec, only useful for v3 and v5\nSynonyms:\nyouid/uuid.oid_uuid\nyouid/uuid oid_uuid","url":"youid/uuid.html#oid_uuid"},{"doc":"youid/uuid","title":"time","content":"pub fn time(uuid: Uuid) -&gt; Int\n Determine the time a UUID was created with Gregorian Epoch\n This is only relevant to a V1 UUID\n UUID&#39;s use 15 Oct 1582 as Epoch and time is measured in 100ns intervals.\n This value is useful for comparing V1 UUIDs but not so much for\n telling what time a UUID was created. See time_posix_microsec and clock_sequence\nSynonyms:\nyouid/uuid.time\nyouid/uuid time","url":"youid/uuid.html#time"},{"doc":"youid/uuid","title":"time_posix_microsec","content":"pub fn time_posix_microsec(uuid: Uuid) -&gt; Int\n Determine the time a UUID was created with Unix Epoch\n This is only relevant to a V1 UUID\n Value is the number of micro seconds since Unix Epoch\nSynonyms:\nyouid/uuid.time_posix_microsec\nyouid/uuid time_posix_microsec","url":"youid/uuid.html#time_posix_microsec"},{"doc":"youid/uuid","title":"to_string","content":"pub fn to_string(uuid: Uuid) -&gt; String\n Convert a UUID to a standard string\nSynonyms:\nyouid/uuid.to_string\nyouid/uuid to_string","url":"youid/uuid.html#to_string"},{"doc":"youid/uuid","title":"url_uuid","content":"pub fn url_uuid() -&gt; Uuid\n url namespace UUID provided by the spec, only useful for v3 and v5\nSynonyms:\nyouid/uuid.url_uuid\nyouid/uuid url_uuid","url":"youid/uuid.html#url_uuid"},{"doc":"youid/uuid","title":"v1","content":"pub fn v1() -&gt; Uuid\n Create a V1 (time-based) UUID with default node and random clock sequence.\nSynonyms:\nyouid/uuid.v1\nyouid/uuid v1","url":"youid/uuid.html#v1"},{"doc":"youid/uuid","title":"v1_custom","content":"pub fn v1_custom(\n  node: V1Node,\n  clock_seq: V1ClockSeq,\n) -&gt; Result(Uuid, Nil)\n Create a V1 (time-based) UUID with custom node and clock sequence.\nSynonyms:\nyouid/uuid.v1_custom\nyouid/uuid v1_custom","url":"youid/uuid.html#v1_custom"},{"doc":"youid/uuid","title":"v1_string","content":"pub fn v1_string() -&gt; String\n Convenience for quickly creating a time-based UUID String with default settings.\nSynonyms:\nyouid/uuid.v1_string\nyouid/uuid v1_string","url":"youid/uuid.html#v1_string"},{"doc":"youid/uuid","title":"v3","content":"pub fn v3(namespace: Uuid, name: BitArray) -&gt; Result(Uuid, Nil)\n Generates a version 3 (name-based, md5 hashed) UUID.\n Name must be a valid sequence of bytes\nSynonyms:\nyouid/uuid.v3\nyouid/uuid v3","url":"youid/uuid.html#v3"},{"doc":"youid/uuid","title":"v4","content":"pub fn v4() -&gt; Uuid\n Generates a version 4 (random) UUID.\nSynonyms:\nyouid/uuid.v4\nyouid/uuid v4","url":"youid/uuid.html#v4"},{"doc":"youid/uuid","title":"v4_string","content":"pub fn v4_string() -&gt; String\n Convenience for quickly creating a random UUID String\nSynonyms:\nyouid/uuid.v4_string\nyouid/uuid v4_string","url":"youid/uuid.html#v4_string"},{"doc":"youid/uuid","title":"v5","content":"pub fn v5(namespace: Uuid, name: BitArray) -&gt; Result(Uuid, Nil)\n Generates a version 5 (name-based, sha1 hashed) UUID.\n name must be a valid sequence of bytes\nSynonyms:\nyouid/uuid.v5\nyouid/uuid v5","url":"youid/uuid.html#v5"},{"doc":"youid/uuid","title":"variant","content":"pub fn variant(uuid: Uuid) -&gt; Variant\n Determine the Variant of a UUID\nSynonyms:\nyouid/uuid.variant\nyouid/uuid variant","url":"youid/uuid.html#variant"},{"doc":"youid/uuid","title":"version","content":"pub fn version(uuid: Uuid) -&gt; Version\n Determine the Version of a UUID\nSynonyms:\nyouid/uuid.version\nyouid/uuid version","url":"youid/uuid.html#version"},{"doc":"youid/uuid","title":"x500_uuid","content":"pub fn x500_uuid() -&gt; Uuid\n x500 namespace UUID provided by the spec, only useful for v3 and v5\nSynonyms:\nyouid/uuid.x500_uuid\nyouid/uuid x500_uuid","url":"youid/uuid.html#x500_uuid"},{"doc":"youid/uuid","title":"youid/uuid","content":" Spec conformant UUID v1, v3, v4, and v5 generation.\n\n Spec conformant UUID decoding for all versions and variants.\n\n Spec: [https://www.ietf.org/rfc/rfc4122.txt](https://www.ietf.org/rfc/rfc4122.txt)\n\n Wikipedia: [https://en.wikipedia.org/wiki/uuid](https://en.wikipedia.org/wiki/uuid)\n\n Unless you have a specific reason otherwise, you probably either want the\n random v4 or the time-based v1 version.","url":"youid/uuid.html"}]);